@@ -661,7 +661,6 @@ where
             Value::Str(n) => emit!(self, n),
             Value::Bin(n) => emit!(self, n),
             Value::Tokens(n) => emit!(self, n),
-            Value::AtText(n) => emit!(self, n),
             Value::Url(n) => emit!(self, n),
             Value::Delimiter(n) => emit!(self, n),
         }
@@ -762,21 +761,21 @@ where
     }
 
     #[emitter]
-    fn emit_declaration_property(&mut self, n: &DeclarationProperty) -> Result {
+    fn emit_declaration_name(&mut self, n: &DeclarationName) -> Result {
         match n {
-            DeclarationProperty::Ident(n) => emit!(self, n),
-            DeclarationProperty::DashedIdent(n) => emit!(self, n),
+            DeclarationName::Ident(n) => emit!(self, n),
+            DeclarationName::DashedIdent(n) => emit!(self, n),
         }
     }
 
     #[emitter]
     fn emit_declaration(&mut self, n: &Declaration) -> Result {
-        emit!(self, n.property);
+        emit!(self, n.name);
         punct!(self, ":");
 
-        let is_custom_property = match n.property {
-            DeclarationProperty::DashedIdent(_) => true,
-            DeclarationProperty::Ident(_) => false,
+        let is_custom_property = match n.name {
+            DeclarationName::DashedIdent(_) => true,
+            DeclarationName::Ident(_) => false,
         };
 
         if !is_custom_property {
@@ -1017,15 +1016,6 @@ where
         }
     }
 
-    #[emitter]
-    fn emit_at_text_value(&mut self, n: &AtTextValue) -> Result {
-        punct!(self, "@");
-        emit!(self, n.name);
-        space!(self);
-
-        emit!(self, n.block);
-    }
-
     #[emitter]
     fn emit_url(&mut self, n: &Url) -> Result {
         emit!(self, n.name);
